@@ -1,4 +1,6 @@
 use bytesize::ByteSize;
+use crate::Icon;
+use super::Iconize;
 use std::fmt;
 
 pub struct NetworkFormatter {
@@ -41,6 +43,12 @@ impl NetworkFormatter {
     }
 }
 
+impl Iconize for NetworkFormatter {
+    fn set_icon(&self, icon: &mut Icon) {
+        icon.find_icon("network-wireless-symbolic")
+    }
+}
+
 impl fmt::Display for NetworkFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         if self.rx_bytes == 0 && self.tx_bytes == 0 {
