@@ -2,10 +2,10 @@
 
 // The flow of citron is as follows:
 //
-//   read   ---->   format   ---->   send
+//   read   ---->   format   ---->   notify
 //    |              |                |
 //    |              |                |
-//    |              |                `---> `send` module
+//    |              |                `---> `notifier` module
 //    |              |
 //    |              `---> `fmt` modules
 //    |
@@ -67,9 +67,8 @@ fn main() {
     }
 
     if opt.uptime {
-        icon.set_icon_contextually(Summary::Uptime);
         notifier.set_summary(Summary::Uptime);
-        notifier.set_body(read::uptime());
+        notifier.set_body(read::uptime(&mut icon));
         notifier.set_icon(&icon);
         notifier.send();
         return;
@@ -84,9 +83,8 @@ fn main() {
     }
 
     if opt.backlight {
-        icon.set_icon_contextually(Summary::Backlight);
         notifier.set_summary(Summary::Backlight);
-        notifier.set_body(read::backlight());
+        notifier.set_body(read::backlight(&mut icon));
         notifier.set_icon(&icon);
         notifier.send();
         return;
@@ -102,18 +100,16 @@ fn main() {
 
     if opt.network {
         let ifname = opt.interface.as_deref();
-        icon.set_icon_contextually(Summary::Network);
         notifier.set_summary(Summary::Network);
-        notifier.set_body(read::network(ifname));
+        notifier.set_body(read::network(ifname, &mut icon));
         notifier.set_icon(&icon);
         notifier.send();
         return;
     }
 
     if opt.memory {
-        icon.set_icon_contextually(Summary::Memory);
         notifier.set_summary(Summary::Memory);
-        notifier.set_body(read::memory());
+        notifier.set_body(read::memory(&mut icon));
         notifier.set_icon(&icon);
         notifier.send();
     }
