@@ -6,10 +6,14 @@ use notify_rust::Timeout;
 use std::fmt;
 
 pub struct Notifier {
+    /// The header of a notification.
     summary: Summary,
-    timeout: u32,
-    icon: String,
+    /// The body of a notification.
     body: String,
+    /// The timeout of a notification.
+    timeout: u32,
+    /// A path to an icon as a string.
+    icon: String,
 }
 
 impl Notifier {
@@ -22,8 +26,8 @@ impl Notifier {
         }
     }
 
-    pub fn set_summary(&mut self, k: Summary) {
-        self.summary = k;
+    pub fn set_summary(&mut self, summary: Summary) {
+        self.summary = summary;
     }
 
     pub fn get_summary(&self) -> String {
@@ -31,24 +35,22 @@ impl Notifier {
     }
 
     pub fn set_icon(&mut self, icon: &Icon) {
-        if icon.is_visible() {
-            if let Some(str) = icon.get_path().to_str() {
-                self.icon = str.to_string();
-            }
+        if let Some(str) = icon.get_path().to_str() {
+            self.icon = str.to_string();
         }
     }
 
-    pub fn set_timeout(&mut self, t: u32) {
-        self.timeout = t;
+    pub fn set_timeout(&mut self, timeout: u32) {
+        self.timeout = timeout;
     }
 
     pub fn get_timeout(&self) -> Timeout {
         Timeout::Milliseconds(self.timeout * 1000)
     }
 
-    pub fn set_body(&mut self, r: Result<String, ReadoutError>) {
-        match r {
-            Ok(r) => self.body = r,
+    pub fn set_body(&mut self, body: Result<String, ReadoutError>) {
+        match body {
+            Ok(b) => self.body = b,
             Err(e) => self.body = e.to_string(),
         }
     }
